@@ -29,7 +29,7 @@ class MWPlot:
     MWPlot class
     """
     def __init__(self, mode='face-on', center=(0, 0) * u.kpc, radius=90750 * u.lyr, unit=u.kpc, coord='galactic',
-                 annotation=True, rot180=False, grayscale=False):
+                 annotation=True, rot90=0, grayscale=False):
         """
         ;:param mode: whether plot edge-on or face-on milkyway
         :type mode: string, either 'face-on' or 'edge-on'
@@ -43,8 +43,8 @@ class MWPlot:
         :type coord: str
         :param annotation: whether use a milkyway background with annotation
         :type annotation: bool
-        :param rot180: whether rotate the image by 180 deg
-        :type rot180: bool
+        :param rot90: number of 90 degree rotation
+        :type rot90: int
         :param grayscale: whether to use grayscale background
         :type grayscale: bool
         """
@@ -63,7 +63,7 @@ class MWPlot:
         self._unit = unit
         self.__coord = coord
         self.__annotation = annotation
-        self.__rot180 = rot180
+        self.__rot90 = rot90
         self.__grayscale = grayscale
 
         self._unit_english = None
@@ -209,8 +209,11 @@ class MWPlot:
         if np.all(np.array([x_left_px, self.__pixels - x_right_px, y_top_px, self.__pixels - y_bottom_px]) >= 0):
             img = img[y_top_px:y_bottom_px, x_left_px:x_right_px]
         else:
-            # create a black image first with 3 channel with the same data type
-            black_img = np.zeros((pixel_radius * 2, pixel_radius * 2, 3), dtype=img.dtype)
+            # create a black/white image first with 3 channel with the same data type
+            if self.__grayscale:
+                black_img = np.ones((pixel_radius * 2, pixel_radius * 2, 3), dtype=img.dtype) * 255
+            else:
+                black_img = np.zeros((pixel_radius * 2, pixel_radius * 2, 3), dtype=img.dtype)
 
             # assign them to temp value
             # just in case the area is outside the images, will fill black pixel
@@ -224,21 +227,17 @@ class MWPlot:
             # Extract available area from pre-compiled first
             img = img[temp_y_top_px:temp_y_bottom_px, temp_x_left_px:temp_x_right_px]
 
-            # fill the black image with the background image
+            # fill the black/white image with the background image
             black_img[top_exceed_px:top_exceed_px + img.shape[0], left_exceed_px:left_exceed_px + img.shape[1], :] = img
 
             # Set the images as the filled black-background image
             img = np.array(black_img)
 
-        if self.__rot180:
-            img = np.rot90(img, 2)
-            self.__ext = [(self.__center[0] + self.__radius - x_shift).value,
-                          (self.__center[0] - self.__radius - x_shift).value,
-                          (self.__center[1] - self.__radius).value, (self.__center[1] + self.__radius).value]
-        else:
-            self.__ext = [(self.__center[0] - self.__radius - x_shift).value,
-                          (self.__center[0] + self.__radius - x_shift).value,
-                          (self.__center[1] + self.__radius).value, (self.__center[1] - self.__radius).value]
+        img = np.rot90(img, self.__rot90)
+        self.__ext = [(self.__center[0] + self.__radius - x_shift).value,
+                      (self.__center[0] - self.__radius - x_shift).value,
+                      (self.__center[1] - self.__radius).value, (self.__center[1] + self.__radius).value]
+
         if self.mode == 'edge-on':
             self.__ext[2] *= -1
             self.__ext[3] *= -1
